@@ -1,6 +1,8 @@
 from functools import reduce
 from itertools import groupby
 from sqlalchemy import BigInteger, desc
+from sqlalchemy.orm import reconstructor
+from sqlalchemy.orm.collections import InstrumentedList
 
 from sqlalchemy_api_handler.bases.accessor import Accessor
 from sqlalchemy_api_handler.bases.errors import ActivityError
@@ -17,18 +19,33 @@ def merged_datum_from_activities(activities,
                   relationships_in(initial, model) if initial else {})
 
 
+def set_joined_relationship_activity_identifiers(self):
+    for key in self.__mapper__.relationships.keys():
+        if key == 'transaction' \
+           or isinstance(getattr(self, key), InstrumentedList):
+            return
+        relationship_activity_identifier_key =  f'{key}ActivityIdentifier'
+        if not hasattr(self, relationship_activity_identifier_key):
+            def get_relationship_activity_identifier(entity):
+                relationship = getattr(entity, key)
+                return relationship.activityIdentifier if hasattr(relationship, 'activityIdentifier') \
+                                                          else None
+            setattr(self.__class__,
+                    relationship_activity_identifier_key,
+                    property(get_relationship_activity_identifier))
+
 
 class Activator(Save):
 
-    def __getattr__(self, key):
-        if key.endswith('ActivityIdentifier'):
-            relationship_name = key.split('ActivityIdentifier')[0]
-            relationship = getattr(self, relationship_name)
-            if hasattr(relationship, 'activityIdentifier'):
-                return relationship.activityIdentifier
-            else:
-                return None
-        return Save.__getattr__(self, key)
+    has_set_relationship_activity_identifier_property = False
+
+    def __init__(self, **initial_datum):
+        set_joined_relationship_activity_identifiers(self)
+        Save.__init__(self, **initial_datum)
+
+    @reconstructor
+    def init_on_load(self):
+        set_joined_relationship_activity_identifiers(self)
 
     @classmethod
     def get_activity(cls):
@@ -64,7 +81,10 @@ class Activator(Save):
                 entity = model(**relationships_in(first_activity.patch, model))
                 entity.activityIdentifier = entity_identifier
                 Activator.save(entity)
-                insert_activity = entity.insertActivity
+                query_filter = (Activity.table_name == model.__tablename__) & \
+                               (Activity.entityIdentifier == entity_identifier) & \
+                               (Activity.verb == 'insert')
+                insert_activity = Activity.query.filter(query_filter).one()
                 insert_activity.dateCreated = first_activity.dateCreated
                 Save.save(insert_activity)
                 # want to make as if first_activity was the inser_activity one
